Skip to contents

This function never searches PATH. With no supplied path, it resolves only the executable installed by this package. Supply one absolute directory or one absolute executable path to use a separately built compatible program.

Usage

rdragmap_executables(directory = character(), dragen_os = character())

Arguments

directory

Empty or one absolute executable directory.

dragen_os

Empty or one absolute dragen-os path.

Value

RdragmapExecutables or an RdragmapInputErrorValue.

Examples

native <- rdragmap_executables()
if (!rdragmap_is_error(native)) native@dragen_os
#> [1] "/tmp/RtmpjLi2BG/temp_libpath200fd87f7d4/Rdragmap/dragen/bin/dragen-os"